@@ -55,20 +55,20 @@ sub parcoord3d
 		$tofile = $main::tofile;
 		#$tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
 		say $tee "\n#Now in Sim::OPT::Takechance.\n";
-		$configfile = $main::configfile; #say "dump(\$configfile): " . dump($configfile);
-		@sweeps = @main::sweeps; #say "dump(\@sweeps): " . dump(@sweeps);
-		@sourcesweeps = @main::sourcesweeps; #say "dump(\@sourcesweeps): " . dump(@sourcesweeps);
+		$configfile = $main::configfile; 
+		@sweeps = @main::sweeps; 
+		@sourcesweeps = @main::sourcesweeps; 
 		@varinumbers = @main::varinumbers; say $tee "dump(\@varinumbers): " . dump(@varinumbers);
 		@mediumiters = @main::mediumiters;
-		@rootnames = @main::rootnames; #say "dump(\@rootnames): " . dump(@rootnames);
-		%vals = %main::vals; #say "dump(\%vals): " . dump(%vals);
+		@rootnames = @main::rootnames; 
+		%vals = %main::vals; 
 		
-		$mypath = $main::mypath;  #say TOFILE "dumpINDESCEND(\$mypath): " . dump($mypath);
-		$exeonfiles = $main::exeonfiles; #say TOFILE "dumpINDESCEND(\$exeonfiles): " . dump($exeonfiles);
+		$mypath = $main::mypath;  
+		$exeonfiles = $main::exeonfiles; 
 		$generatechance = $main::generatechance; 
 		$file = $main::file;
 		$preventsim = $main::preventsim;
-		$fileconfig = $main::fileconfig; #say TOFILE "dumpINDESCEND(\$fileconfig): " . dump($fileconfig); # NOW GLOBAL. TO MAKE IT PRIVATE, FIX PASSING OF PARAMETERS IN CONTRAINTS PROPAGATION SECONDARY SUBROUTINES
+		$fileconfig = $main::fileconfig; 
 		$outfile = $main::outfile;
 		$target = $main::target;
 		
@@ -165,7 +165,7 @@ sub parcoord3d
 					if ( $rowelt =~ /-/ )
 					{
 						my @vardata = split( /-/ , $rowelt );
-						#say "VARDATA: " . Dumper(@vardata);
+						
 						push ( @linedata, [ @vardata ] );
 					}
 					else
@@ -321,25 +321,25 @@ sub parcoord3d
 		open (WRITEFILE, ">$writefile") or die;
 		my $countgroup = 0;
 		foreach my $e (@plotdata)
-		{#print "INLEVEL2\n";
+		{
 			my @elts = @{$e};
 			my @newnewbag;
 			my $counter = 0;
 			foreach my $elm (@elts)
-			{#print "INLEVEL3\n";
+			{
 				my @elms = @{$elm};
 				my @cutelms = @elms[0..2]; # PUT ..2 IF ALSO THE THIRD AXIS HAS TO BE CHECKED FOR NON-REPETITIONS, PUT 1 OTHERWISE.
 				my $counthit = -1;
 				foreach my $el (@plotdata)
-				{#print "INLEVEL4\n";
+				{
 					my @els = @{$el};
 					foreach my $elem (@els)
-					{#print "INLEVEL5,6\n";
+					{
 						my @elems = @{$elem};
 						my @cutelems = @elems[0..2]; # PUT ..2 IF ALSO THE THIRD AXIS HAS TO BE CHECKED FOR NON-REPETITIONS, PUT 1 OTHERWISE.
 						if (@cutelms ~~ @cutelems)
-						{#print "INLEVEL7\n";
-							#print "CUTELMS: " . dump(@cutelms) . "\nCUTELEMS: " . dump(@cutelems) . "\n";
+						{
+							
 							$counthit++;
 							print "COUNTGROUP: $countgroup, HIT! $counthit\n";
 						
@@ -390,15 +390,15 @@ sub parcoord3d
 			{
 				my @coords = @{$elt};
 				my @nextcoords = @{$elts[$countpar+1]};
-				#print "COORDS: " . dump(@coords);
-				#print "NEXTCOORDS: " . dump(@nextcoords);
+				
+				
 				my @newcoords;
 				push( @newcoords, [ @coords ] );
 				push( @newcoords, [ ($coords[0] - ($yspacing * $offset ) ) , $coords[1] , $coords[2], $coords[3] ] );
 				push( @newcoords, [ ($coords[0] - ($yspacing * $offset ) ) , $coords[1] , ( $coords[2] - ($yspacing * $offset ) ) , $coords[3] ] );
 				push( @newcoords, [ $coords[0], $coords[1] , ( $coords[2] - ($yspacing * $offset ) ) , $coords[3] ] );
 				push( @newplotdatabottom, [ @newcoords ] );
-				#print "DONE1 BOTTOM COUNTGROUP $countgroup COUNTPAR $countpar\n";
+				
 			
 				my @newcoords;
 				unless ($countpar == $#elts)
@@ -409,7 +409,7 @@ sub parcoord3d
 					push( @newcoords, [ @nextcoords] );
 					push( @newplotdatafront, [ @newcoords ] );
 				}
-				#print "DONE2 FRONT COUNTPAR $countpar\n";
+				
 
 				my @newcoords;
 				unless ($countpar == $#elts)
@@ -420,7 +420,7 @@ sub parcoord3d
 					push( @newcoords, [ ($nextcoords[0] - ($yspacing * $offset ) ) , $nextcoords[1] , $nextcoords[2], $nextcoords[3] ] );
 					push( @newplotdataleft, [ @newcoords ] );
 				}
-				#print "DONE3 LEFT COUNTPAR $countpar\n";
+				
 
 				my @newcoords;
 				unless ($countpar == $#elts)
@@ -431,7 +431,7 @@ sub parcoord3d
 					push( @newcoords, [ ($nextcoords[0] - ($yspacing * $offset ) ) , $nextcoords[1] , ( $nextcoords[2] - ($yspacing * $offset ) ) , $nextcoords[3] ] );
 					push( @newplotdataback, [ @newcoords ] );
 				}
-				#print "DONE4 BACK COUNTPAR $countpar\n";
+				
 
 				my @newcoords;
 				unless ($countpar == $#elts)
@@ -442,8 +442,8 @@ sub parcoord3d
 					push( @newcoords, [ $nextcoords[0], $nextcoords[1] , ( $nextcoords[2] - ($yspacing * $offset ) ) , $nextcoords[3] ] );
 					push( @newplotdataright, [ @newcoords ] );
 				}
-				#print "DONE5 RIGHT COUNTPAR $countpar\n";
-				# print "COUNTPAR: $countpar\n";
+				
+				
 				$countpar++;
 			}
 		
@@ -456,7 +456,7 @@ sub parcoord3d
 				push(@newnewdata, @newplotdatabottom );
 			}
 
-			# print "COUNTGROUP: $countgroup\n";
+			
 			$countgroup++;
 		}
 		print TRANSITIONAL dump(@newnewdata);
